#!/bin/bash

. /usr/share/eole/FonctionsEoleNg
if [ "$1" = "" ] || [ ! "$2" = "" ]; then
	EchoRouge "usage : $0 nom_du_module"
	exit 1
fi
NAME=$1
NET="192.168.0.0/24"
ROOTLXC=/var/lib/lxc
ROOT=${ROOTLXC}/default
DEV=${ROOT}/dev
PKG=$ROOTLXC/eole.packages.tgz
ROOTFS=$ROOTLXC/$NAME/rootfs
LOG="/var/log/isalation.log"
rm -f $LOG
function execute() {
	$1 >> $LOG 2>&1
	if [ ! $? = 0 ]; then
		EchoRouge "Erreur à la création du conteneur."
		EchoRouge "Pour plus d'information, lire les logs :"
		EchoRouge "$LOG"
		exit 1
	fi
}

if [ ! -e $PKG  ]; then
	echo "Création de l'image du conteneur (veuillez patienter)"
	if [ -d $ROOT ]; then
	    EchoRouge "$ROOT existe déjà"
	    exit 1
	fi
	execute "debootstrap --variant=minbase --arch i386 lucid $ROOT http://archive.ubuntu.com/ubuntu/"
	if [ ! -d $DEV ]; then
	    EchoRouge "Ne trouve pas $DEV"
	    exit 1
	fi
	echo "Configuration de l'image du conteneur"
	rm -rf ${DEV}
	mkdir ${DEV}
	mknod -m 666 ${DEV}/null c 1 3
	mknod -m 666 ${DEV}/zero c 1 5
	mknod -m 666 ${DEV}/random c 1 8
	mknod -m 666 ${DEV}/urandom c 1 9
	mkdir -m 755 ${DEV}/pts
	mkdir -m 1777 ${DEV}/shm
	mknod -m 666 ${DEV}/tty c 5 0
	mknod -m 666 ${DEV}/tty0 c 4 0
	mknod -m 666 ${DEV}/tty1 c 4 1
	mknod -m 666 ${DEV}/tty2 c 4 2
	mknod -m 666 ${DEV}/tty3 c 4 3
	mknod -m 666 ${DEV}/tty4 c 4 4
	mknod -m 600 ${DEV}/console c 5 1
	mknod -m 666 ${DEV}/full c 1 7
	mknod -m 600 ${DEV}/initctl p
	mknod -m 666 ${DEV}/ptmx c 5 2

	echo "Installatino des paquets supplémentaire"
	cp -f /etc/apt/sources.list $ROOT/etc/apt/
	execute "chroot $ROOT apt-get update"
	execute "chroot $ROOT apt-get install --force-yes -y language-pack-fr gpgv"
	execute "chroot $ROOT update-locale LANG=\"fr_FR.UTF-8\" LANGUAGE=\"fr_FR.UTF-8\" LC_ALL=\"fr_FR.UTF-8\""
	rm -f $ROOT/etc/init/tty{4,5,6}.conf
	mkdir -p $ROOT/var/run/network
	touch $ROOT/var/run/network/ifstate
	sed -i '/none            \/proc /d' $ROOT/lib/init/fstab
	sed -i '/none            \/sys /d' $ROOT/lib/init/fstab
	sed -i '/none            \/dev /d' $ROOT/lib/init/fstab
	sed -i 's@start on filesystem and net-device-up IFACE=lo@start on filesystem@g' $ROOT/etc/init/rc-sysinit.conf
	echo "# LXC – Fix init sequence to have LXC containers boot with upstart

# description “Fix LXC container - Lucid”

start on startup

task
pre-start script
mount -t proc proc /proc
mount -t devpts devpts /dev/pts
mount -t sysfs sys /sys
mount -t tmpfs varrun /var/run
mount -t tmpfs varlock /var/lock
mkdir -p /var/run/network
touch /var/run/utmp
chmod 664 /var/run/utmp
chown root.utmp /var/run/utmp
if [ \"\$(find /etc/network/ -name upstart -type f)\" ]; then
	chmod -x /etc/network/*/upstart || true
fi
end script

script
start networking
initctl emit filesystem --no-wait
initctl emit local-filesystems --no-wait
initctl emit virtual-filesystems --no-wait
init 2
end script" > $ROOT/etc/init/lxc.conf
	cd $ROOT
	echo "Compression de l'image du conteneur"
	execute "tar -zcf $PKG *"
	cd -
	rm -rf $ROOT
fi
[ -d $ROOTFS ] && echo "Le conteneur $NAME existe déjà" && exit 0
echo "Installation du conteneur $NAME (veuillez patienter)"
#echo "debootstrap --unpack-tarball $PKG lucid $ROOTFS"
#debootstrap --unpack-tarball $PKG lucid $ROOTFS
mkdir -p $ROOTFS
cd $ROOTFS
execute "tar -xf $PKG"
execute "chroot $ROOTFS apt-get update"
execute "chroot $ROOTFS apt-get install $NAME-pkg --force-yes -y"
echo "Configuration du conteneur $NAME"
echo "lxc.utsname = $NAME
lxc.tty = 4
lxc.network.type = veth
lxc.network.flags = up
lxc.network.link = br0
lxc.network.name = eth0
lxc.network.mtu = 1500
lxc.network.ipv4 = $NET
lxc.rootfs = $ROOTFS
lxc.cgroup.devices.deny = a
# /dev/null and zero
lxc.cgroup.devices.allow = c 1:3 rwm
lxc.cgroup.devices.allow = c 1:5 rwm
# consoles
lxc.cgroup.devices.allow = c 5:1 rwm
lxc.cgroup.devices.allow = c 5:0 rwm
lxc.cgroup.devices.allow = c 4:0 rwm
lxc.cgroup.devices.allow = c 4:1 rwm
# /dev/{,u}random
lxc.cgroup.devices.allow = c 1:9 rwm
lxc.cgroup.devices.allow = c 1:8 rwm
# /dev/pts/* - pts namespaces are "coming soon"
lxc.cgroup.devices.allow = c 136:* rwm
lxc.cgroup.devices.allow = c 5:2 rwm
# rtc
lxc.cgroup.devices.allow = c 254:0 rwm" > $ROOTLXC/$NAME/config

echo "Démarrage du conteneur $NAME"
#lxc-create -f $ROOTLXC/$NAME/config -n $NAME
execute "lxc-start -n $NAME -d"
exit 0
